==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/ktorrent/pref/btpref.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KT_BTPREF_H
#define KT_BTPREF_H

#include <interfaces/prefpageinterface.h>
#include "ui_btpref.h"

namespace kt
{

    class BTPref : public PrefPageInterface, public Ui_BTPref
    {
        Q_OBJECT
    public:
        BTPref(QWidget* parent);
        virtual ~BTPref();

        void loadSettings();
    };
}

#endif // KT_BTPREF_H

==> ktorrent-5.0.90.tar.xz: ktorrent-5.0.90/ktorrent/pref/btpref.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_BTPREF_H
#define KT_BTPREF_H

#include <interfaces/prefpageinterface.h>
#include "ui_btpref.h"

namespace kt
{

    class BTPref : public PrefPageInterface, public Ui_BTPref
    {
        Q_OBJECT
    public:
        BTPref(QWidget* parent);
        ~BTPref();

        void loadSettings() override;
    };
}

#endif // KT_BTPREF_H
